(function() {
  var $, $SUBJECT, _, assert, check, checkDeep;

  $ = require('./../index');

  _ = $._;

  assert = require('assert');

  check = assert.equal;

  checkDeep = assert.deepEqual;

  $SUBJECT = [
    1024, 'hello world', true, [1, 2, 3], {
      a: 1,
      b: 2
    }, function() {
      return null;
    }, new Date(), new Error('All Right'), new Buffer('String'), null, void 0, 0/0
  ];

  describe('$.log()', function() {
    return it('$.log()', function() {
      return check($.log, console.log);
    });
  });

  describe('$.parseJson()', function() {
    return _.each($SUBJECT, function(a, i) {
      var p, type;
      p = $SUBJECT[i];
      type = $.type(p);
      if (type === 'number' && _.isNaN(p)) {
        it('NaN', function() {
          return check(_.isEqual($.parseJson(p), a), true);
        });
        return;
      }
      return it(type, function() {
        return checkDeep($.parseJson(p), a);
      });
    });
  });

  describe('$.parsePts()', function() {
    var LIST;
    LIST = [[0, '0'], [100, '100'], [1e3, '1,000'], [1e4, '10,000'], [1e5, '10万'], [1234567, '123.4万']];
    return _.each(LIST, function(a) {
      return it(a[0].toString(), function() {
        return check($.parsePts(a[0]), a[1]);
      });
    });
  });

  describe('$.parseShortDate()', function() {
    var LIST;
    LIST = [['2012.12.21', '20121221'], ['1999.1.1', '19990101'], ['2050.2.28', '20500228']];
    return _.each(LIST, function(a) {
      return it(a[0], function() {
        return check($.parseShortDate($.timeStamp(a[0])), a[1]);
      });
    });
  });

  describe('$.parseString()', function() {
    var LIST;
    LIST = ['1024', 'hello world', 'true', '[1,2,3]', '{"a":1,"b":2}', $SUBJECT[5].toString(), $SUBJECT[6].toString(), $SUBJECT[7].toString(), $SUBJECT[8].toString(), 'null', 'undefined', 'NaN'];
    return _.each(LIST, function(a, i) {
      var p, type;
      p = $SUBJECT[i];
      type = $.type(p);
      if (type === 'number' && _.isNaN(p)) {
        type = 'NaN';
      }
      return it(type, function() {
        return check($.parseString(p), a);
      });
    });
  });

  describe('$.parseTemp()', function() {
    return it('$.parseTemp()', function() {
      var arg, res, temp;
      temp = '[a] is falling love with [b]!';
      arg = {
        a: 'Homura',
        b: 'Madoka'
      };
      res = $.parseTemp(temp, arg);
      return check(res, 'Homura is falling love with Madoka!');
    });
  });

  describe('$.timeStamp()', function() {
    var LIST, now, res, ts;
    it('null', function() {
      var res, ts;
      res = $.timeStamp();
      ts = _.floor($.now(), -3);
      return check(res, ts);
    });
    now = _.now();
    res = $.timeStamp(now);
    ts = _.floor(now, -3);
    it(now.toString(), function() {
      return check(res, ts);
    });
    LIST = [[2012, 12, 21], [1997, 7, 1], [1970, 1, 1]];
    _.each(LIST, function(a, i) {
      var date, p;
      res = $.timeStamp(p = a.join('.'));
      date = new Date();
      date.setFullYear(a[0], a[1] - 1, a[2]);
      date.setHours(0, 0, 0, 0);
      ts = _.floor(date.getTime(), -3);
      return it(p, function() {
        return check(res, ts);
      });
    });
    LIST = [[2012, 12, 21, 12, 21], [1997, 7, 1, 19, 30], [1970, 1, 1, 8, 1]];
    return _.each(LIST, function(a, i) {
      var date, p;
      res = $.timeStamp(p = (a.slice(0, 3).join('.')) + " " + (a.slice(3).join(':')));
      date = new Date();
      date.setFullYear(a[0], a[1] - 1, a[2]);
      date.setHours(a[3], a[4], 0, 0);
      ts = _.floor(date.getTime(), -3);
      return it(p, function() {
        return check(res, ts);
      });
    });
  });

}).call(this);
